==> nandb_2.0.7.tar.gz: nandb/README.md <==

# `nandb` <img src="man/figures/logo.png" align="right" height=140/>

Calculation of molecular number and brightness from fluorescence
microscopy image series. The software was published in a [2016
paper](https://doi.org/10.1093/bioinformatics/btx434). The seminal paper
for the technique is [Digman et
al. 2008](https://doi.org/10.1529/biophysj.107.114645). A
[review](https://doi.org/10.1016/j.ymeth.2017.12.001) of the technique
was published in [2017](https://doi.org/10.1016/j.ymeth.2017.12.001).

[![Travis-CI Build
Status](https://travis-ci.org/rorynolan/nandb.svg?branch=master)](https://travis-ci.org/rorynolan/nandb)
[![AppVeyor Build
Status](https://ci.appveyor.com/api/projects/status/github/rorynolan/nandb?branch=master&svg=true)](https://ci.appveyor.com/project/rorynolan/nandb)
[![Coverage
Status](https://img.shields.io/codecov/c/github/rorynolan/nandb/master.svg)](https://codecov.io/github/rorynolan/nandb?branch=master)

[![CRAN\_Status\_Badge](http://www.r-pkg.org/badges/version/nandb)](https://cran.r-project.org/package=nandb)
![RStudio CRAN
downloads](http://cranlogs.r-pkg.org/badges/grand-total/nandb) ![RStudio
CRAN monthly downloads](http://cranlogs.r-pkg.org/badges/nandb)
[![Rdocumentation](http://www.rdocumentation.org/badges/version/nandb)](http://www.rdocumentation.org/packages/nandb)

[![Project Status: Active – The project has reached a stable, usable
state and is being actively
developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://www.tidyverse.org/lifecycle/#stable)

## Installation

You can install the release version of `nandb` from
[CRAN](https://CRAN.R-project.org/package=nandb) with:

``` r
install.packages("nandb")
```

You can install the (unstable) development version of `nandb` from
[GitHub](https://github.com/rorynolan/nandb/) with:

``` r
devtools::install_github("rorynolan/nandb")
```

I highly recommend using the release version. The dev version is just
for the ultra-curious and should be thought of as unreliable.

## How to use the package

See the package website at <https://rorynolan.github.io/nandb>.

## Contribution

Contributions to this package are welcome. The preferred method of
contribution is through a github pull request. Feel free to contact me
by creating an issue. Please note that this project is released with a
[Contributor Code of
Conduct](https://github.com/rorynolan/nandb/blob/master/CONDUCT.md). By
participating in this project you agree to abide by its terms.

==> nandb_2.0.8.tar.gz: nandb/README.md <==

# `nandb` <img src="man/figures/logo.png" align="right" height=140/>

Calculation of molecular number and brightness from fluorescence
microscopy image series. The software was published in a [2016
paper](https://doi.org/10.1093/bioinformatics/btx434). The seminal paper
for the technique is [Digman et
al. 2008](https://doi.org/10.1529/biophysj.107.114645). A
[review](https://doi.org/10.1016/j.ymeth.2017.12.001) of the technique
was published in [2017](https://doi.org/10.1016/j.ymeth.2017.12.001).

[![Travis-CI Build
Status](https://travis-ci.org/rorynolan/nandb.svg?branch=master)](https://travis-ci.org/rorynolan/nandb)
[![AppVeyor Build
Status](https://ci.appveyor.com/api/projects/status/github/rorynolan/nandb?branch=master&svg=true)](https://ci.appveyor.com/project/rorynolan/nandb)
[![Coverage
Status](https://img.shields.io/codecov/c/github/rorynolan/nandb/master.svg)](https://codecov.io/github/rorynolan/nandb?branch=master)

[![CRAN\_Status\_Badge](http://www.r-pkg.org/badges/version/nandb)](https://cran.r-project.org/package=nandb)
![RStudio CRAN
downloads](http://cranlogs.r-pkg.org/badges/grand-total/nandb) ![RStudio
CRAN monthly downloads](http://cranlogs.r-pkg.org/badges/nandb)

[![Project Status: Active – The project has reached a stable, usable
state and is being actively
developed.](http://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html)

## Installation

You can install the release version of `nandb` from
[CRAN](https://CRAN.R-project.org/package=nandb) with:

``` r
install.packages("nandb")
```

You can install the (unstable) development version of `nandb` from
[GitHub](https://github.com/rorynolan/nandb/) with:

``` r
devtools::install_github("rorynolan/nandb")
```

I highly recommend using the release version. The dev version is just
for the ultra-curious and should be thought of as unreliable.

## How to use the package

See the package website at <https://rorynolan.github.io/nandb/>.

## Contribution

Contributions to this package are welcome. The preferred method of
contribution is through a github pull request. Feel free to contact me
by creating an issue. Please note that this project is released with a
[Contributor Code of
Conduct](https://github.com/rorynolan/nandb/blob/master/CONDUCT.md). By
participating in this project you agree to abide by its terms.
